@@ -1,5 +1,5 @@
 package Bio::Roary::ExtractProteomeFromGFF;
-$Bio::Roary::ExtractProteomeFromGFF::VERSION = '3.6.6';
+$Bio::Roary::ExtractProteomeFromGFF::VERSION = '3.6.7';
 # ABSTRACT: Take in a GFF file and create protein sequences in FASTA format
 
 
@@ -70,9 +70,25 @@ sub _unfiltered_output_filename {
 
 sub _create_nucleotide_fasta_file_from_gff {
     my ($self) = @_;
-    my $cmd = 'sed -n \'/^>/,//p\' ' . $self->gff_file . ' > ' . $self->_nucleotide_fasta_file_from_gff_filename;
-    $self->logger->debug($cmd);
-    system($cmd);
+    
+    open(my $input_fh, $self->gff_file);
+    open(my $output_fh, '>', $self->_nucleotide_fasta_file_from_gff_filename);
+    my $at_sequence = 0;
+    while(<$input_fh>)
+    {
+	    my $line = $_;
+	    if($line =~/^>/)
+	    {
+	    	$at_sequence = 1;
+	    }
+	    
+	    if($at_sequence == 1)
+	    {
+		    print {$output_fh} $line;
+	    }
+    }
+    close($input_fh);
+    close($output_fh);
 }
 
 sub _extract_nucleotide_regions {
@@ -201,7 +217,7 @@ Bio::Roary::ExtractProteomeFromGFF - Take in a GFF file and create protein seque
 
 =head1 VERSION
 
-version 3.6.6
+version 3.6.7
 
 =head1 SYNOPSIS
 
