@@ -1,5 +1,5 @@
 package Bio::Roary::Output::GroupsMultifastaNucleotide;
-$Bio::Roary::Output::GroupsMultifastaNucleotide::VERSION = '3.6.6';
+$Bio::Roary::Output::GroupsMultifastaNucleotide::VERSION = '3.6.7';
 # ABSTRACT:  Take in a GFF files and a groups file and output one multifasta file per group with nucleotide sequences.
 
 
@@ -108,16 +108,27 @@ sub _extracted_nucleotide_fasta_file_from_bed_filename {
     return join( '.', ( $self->output_filename, 'intermediate.extracted.fa' ) );
 }
 
-
-
 sub _create_nucleotide_fasta_file_from_gff {
     my ($self) = @_;
-    my $cmd =
-        'sed -n \'/^>/,//p\' '
-      . $self->gff_file
-      . ' > '
-      . $self->_nucleotide_fasta_file_from_gff_filename;
-    system($cmd);
+    
+    open(my $input_fh, $self->gff_file);
+    open(my $output_fh, '>', $self->_nucleotide_fasta_file_from_gff_filename);
+    my $at_sequence = 0;
+    while(<$input_fh>)
+    {
+	    my $line = $_;
+	    if($line =~/^>/)
+	    {
+	    	$at_sequence = 1;
+	    }
+	    
+	    if($at_sequence == 1)
+	    {
+		    print {$output_fh} $line;
+	    }
+    }
+    close($input_fh);
+    close($output_fh);
 }
 
 sub _nucleotide_fasta_file_from_gff_filename {
@@ -194,7 +205,7 @@ Bio::Roary::Output::GroupsMultifastaNucleotide - Take in a GFF files and a group
 
 =head1 VERSION
 
-version 3.6.6
+version 3.6.7
 
 =head1 SYNOPSIS
 
